<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: PACKAGE VERSION
Report-Msgid-Bugs-To: 
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2010-03-14 16:37+0000
Last-Translator: DiegoJ &lt;diegojromerolopez@gmail.com&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2010-04-22 14:00+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Equipo</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servicio</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Gracias a:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Este programa esta licenciado a usted bajo los terminos de la Licencia General Publica GNU version 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Buscar texto</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texto no encontrado.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Actividades CIFS/SMB</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Mensaje a enviar</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Mensaje para enviar a %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>¿Desea realmente desconectar al usuario %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Si</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Mandar mensajes a todos los usuarios</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>enviar mensaje a</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Desconectar usuario</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>La actualización está disponible</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Una nueva versión de %1 está disponible</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Puede descargarlo desde aquí: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Intervalo:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Mostrar compartidos ocultos (compartido$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Mostrar compartidos ocultos</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Notificaciones y registro</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Limitar registro:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Iconizar QtSmbstatus en el área de notificación</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Mostrar las actividades en &quot;Mensajes de globo&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Estado de los mensajes de notificación</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Registrar actividades SMB/CIFS</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Varios</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Revisar automaticamente por actualizaciones</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>Una nueva versión esta disponible</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Conexión</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Nombre de usuario por defecto:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Autoconectar</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Dirección de host predeterminada:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Usuario(defecto : usuario = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Dirección del equipo</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Conectar/Desconectar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>Bu&amp;scar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Acerca de QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Configurar cliente</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Configurar el cliente de QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Maquina</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Buscar Maquina</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Usuario</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Buscar usuario</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>Compartir &amp;abierto</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>Archivo b&amp;loqueado</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Siguie&amp;nte</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Buscar texto</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Buscar texto</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>Co&amp;nectar</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Ver Actividades</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Guardar registro</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Ver/ocultar partes</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Ver/ocultar archivos</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>root</source>
        <translation>superusuario</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>exit</source>
        <translation>salir</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Conexión en progreso en %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Conectar al servidor</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Conección cerrada</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
